var _missingExportShim=void 0;function x (arg) {
  sideEffect(arg);
}export{_missingExportShim as missingExport,_missingExportShim as missingFn,x};